pub struct ParseMuteActionError(pub String);Expand description
Error returned when parsing an invalid mute action string.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for ParseMuteActionError
impl Clone for ParseMuteActionError
Sourcefn clone(&self) -> ParseMuteActionError
fn clone(&self) -> ParseMuteActionError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParseMuteActionError
impl Debug for ParseMuteActionError
Sourceimpl Display for ParseMuteActionError
impl Display for ParseMuteActionError
impl Eq for ParseMuteActionError
Sourceimpl Error for ParseMuteActionError
impl Error for ParseMuteActionError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for ParseMuteActionError
impl PartialEq for ParseMuteActionError
Sourcefn eq(&self, other: &ParseMuteActionError) -> bool
fn eq(&self, other: &ParseMuteActionError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ParseMuteActionError