Module event

Module event 

ESL event types and structures

Structs

EslEvent
ESL Event structure containing headers and optional body
EventSubscription
Declarative description of an ESL event subscription.
EventSubscriptionError
Error returned when an EventSubscription builder method receives invalid input.
ParseEventFormatError
Error returned when parsing an invalid event format string.
ParseEventTypeError
Error returned when parsing an unknown event type string.
ParsePriorityError
Error returned when parsing an invalid priority string.

Enums

EslEventPriority
Event priority levels matching FreeSWITCH esl_priority_t
EslEventType
FreeSWITCH event types matching the canonical order from esl_event.h and switch_event.c EVENT_NAMES[].
EventFormat
Event format types supported by FreeSWITCH ESL