Module lookup

Module lookup 

Shared trait for typed header lookups from any key-value store.

HeaderLookup provides convenience accessors (typed channel state, call direction, timetable extraction, etc.) to any type that can look up headers and variables by name. Implement the two required methods and get everything else for free.

Traits

HeaderLookup
Trait for looking up ESL headers and channel variables from any key-value store.