pub struct ParseGatewayRegStateError(pub String);Expand description
Error returned when parsing an invalid gateway reg state string.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for ParseGatewayRegStateError
impl Clone for ParseGatewayRegStateError
Sourcefn clone(&self) -> ParseGatewayRegStateError
fn clone(&self) -> ParseGatewayRegStateError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParseGatewayRegStateError
impl Debug for ParseGatewayRegStateError
Sourceimpl Display for ParseGatewayRegStateError
impl Display for ParseGatewayRegStateError
Sourceimpl Error for ParseGatewayRegStateError
impl Error for ParseGatewayRegStateError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for ParseGatewayRegStateError
impl PartialEq for ParseGatewayRegStateError
Sourcefn eq(&self, other: &ParseGatewayRegStateError) -> bool
fn eq(&self, other: &ParseGatewayRegStateError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ParseGatewayRegStateError
impl StructuralPartialEq for ParseGatewayRegStateError