pub struct ParseSofiaEventSubclassError(pub String);Expand description
Error returned when parsing an unrecognized Sofia event subclass.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for ParseSofiaEventSubclassError
impl Clone for ParseSofiaEventSubclassError
Sourcefn clone(&self) -> ParseSofiaEventSubclassError
fn clone(&self) -> ParseSofiaEventSubclassError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParseSofiaEventSubclassError
impl Debug for ParseSofiaEventSubclassError
Sourceimpl Error for ParseSofiaEventSubclassError
impl Error for ParseSofiaEventSubclassError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for ParseSofiaEventSubclassError
impl PartialEq for ParseSofiaEventSubclassError
Sourcefn eq(&self, other: &ParseSofiaEventSubclassError) -> bool
fn eq(&self, other: &ParseSofiaEventSubclassError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ParseSofiaEventSubclassError
impl StructuralPartialEq for ParseSofiaEventSubclassError