pub struct SipCallInfo(/* private fields */);Expand description
Parsed SIP Call-Info header value. Contains zero or more entries.
use sip_header::SipCallInfo;
let raw = "<urn:example:call:123>;purpose=emergency-CallId,<https://example.com/data>;purpose=EmergencyCallData.ServiceInfo";
let info = SipCallInfo::parse(raw).unwrap();
assert_eq!(info.entries().len(), 2);
assert_eq!(info.entries()[0].purpose(), Some("emergency-CallId"));Implementations
Sourceimpl SipCallInfo
impl SipCallInfo
Sourcepub fn parse(raw: &str) -> Result<SipCallInfo, SipCallInfoError>
pub fn parse(raw: &str) -> Result<SipCallInfo, SipCallInfoError>
Parse a standard comma-separated Call-Info header value (RFC 3261 20.9).
Sourcepub fn from_entries<'a>(
entries: impl IntoIterator<Item = &'a str>,
) -> Result<SipCallInfo, SipCallInfoError>
pub fn from_entries<'a>( entries: impl IntoIterator<Item = &'a str>, ) -> Result<SipCallInfo, SipCallInfoError>
Build from pre-split header entries.
Each entry should be a single <uri>;param=value string. Use this
when entries have already been split by an external mechanism (e.g.
a transport-specific array encoding).
Sourcepub fn entries(&self) -> &[SipCallInfoEntry]
pub fn entries(&self) -> &[SipCallInfoEntry]
The parsed entries as a slice.
Sourcepub fn into_entries(self) -> Vec<SipCallInfoEntry>
pub fn into_entries(self) -> Vec<SipCallInfoEntry>
Consume self and return the entries as a Vec.