VariableName

Trait VariableName 

pub trait VariableName {
    // Required method
    fn as_str(&self) -> &str;
}
Trait for typed channel variable name enums.

Implement this on variable name enums to use them with HeaderLookup::variable() and variable_str(). For variables not covered by any typed enum, use variable_str().

Required Methods

fn as_str(&self) -> &str

Wire-format variable name (e.g. "sip_call_id").

Implementors