ESL event types and structures
Structs
- EslEvent
- ESL Event structure containing headers and optional body
- Event
Subscription - Declarative description of an ESL event subscription.
- Event
Subscription Error - Error returned when an
EventSubscriptionbuilder method receives invalid input. - Parse
Event Format Error - Error returned when parsing an invalid event format string.
- Parse
Event Type Error - Error returned when parsing an unknown event type string.
- Parse
Priority Error - Error returned when parsing an invalid priority string.
Enums
- EslEvent
Priority - Event priority levels matching FreeSWITCH
esl_priority_t - EslEvent
Type - FreeSWITCH event types matching the canonical order from
esl_event.handswitch_event.cEVENT_NAMES[]. - Event
Format - Event format types supported by FreeSWITCH ESL