Module variables

Module variables 

Channel variable types: format parsers (ARRAY::, SIP multipart) and typed variable name enums.

Structs

EslArray
Parses FreeSWITCH ARRAY::item1|:item2|:item3 format
InvalidHeaderName
Error returned when a raw header name contains invalid characters.
MultipartBody
Parses variable_sip_multipart ARRAY:: format.
MultipartItem
A single part from a SIP multipart body
ParseChannelVariableError
Error returned when parsing an unrecognized channel variable name.
ParseSipPassthroughError
Error returned when parsing an unrecognized passthrough header variable name.
ParseSofiaVariableError
Error returned when parsing an unrecognized Sofia variable name.
SipPassthroughHeader
A FreeSWITCH SIP passthrough header variable name.

Enums

ChannelVariable
Core FreeSWITCH channel variable names (the part after the variable_ prefix).
SipHeaderPrefix
FreeSWITCH SIP header passthrough variable prefix.
SofiaVariable
mod_sofia / SIP channel variable names (the part after the variable_ prefix).

Traits

VariableName
Trait for typed channel variable name enums.