Channel variable types: format parsers (ARRAY::, SIP multipart) and typed
variable name enums.
Structs
- EslArray
- Parses FreeSWITCH
ARRAY::item1|:item2|:item3format - Invalid
Header Name - Error returned when a raw header name contains invalid characters.
- Multipart
Body - Parses
variable_sip_multipartARRAY:: format. - Multipart
Item - A single part from a SIP multipart body
- Parse
Channel Variable Error - Error returned when parsing an unrecognized channel variable name.
- Parse
SipPassthrough Error - Error returned when parsing an unrecognized passthrough header variable name.
- Parse
Sofia Variable Error - Error returned when parsing an unrecognized Sofia variable name.
- SipPassthrough
Header - A FreeSWITCH SIP passthrough header variable name.
Enums
- Channel
Variable - Core FreeSWITCH channel variable names (the part after the
variable_prefix). - SipHeader
Prefix - FreeSWITCH SIP header passthrough variable prefix.
- Sofia
Variable - mod_sofia / SIP channel variable names (the part after the
variable_prefix).
Traits
- Variable
Name - Trait for typed channel variable name enums.