Channel variable types: format parsers (ARRAY::, SIP multipart) and typed
variable name enums.
Structs
- EslArray
- Parses FreeSWITCH
ARRAY::item1|:item2|:item3format - History
Info - Parsed History-Info header value (RFC 7044).
- History
Info Entry - A single entry from a History-Info header (RFC 7044).
- History
Info Reason - Parsed RFC 3326 Reason header value extracted from a History-Info URI.
- Multipart
Body - Parses
variable_sip_multipartARRAY:: format. - Multipart
Item - A single part from a SIP multipart body
- Parse
Channel Variable Error - Error returned when parsing an unrecognized channel variable name.
- Parse
SipInvite Header Error - Error returned when parsing an unrecognized SIP invite header variable name.
- Parse
Sofia Variable Error - Error returned when parsing an unrecognized Sofia variable name.
- SipCall
Info - Parsed SIP Call-Info header value. Contains zero or more entries.
- SipCall
Info Entry - One entry from a SIP Call-Info header:
<uri>;key=value;key=value. - SipGeolocation
- Parsed SIP Geolocation header value (RFC 6442).
Enums
- Channel
Variable - Core FreeSWITCH channel variable names (the part after the
variable_prefix). - History
Info Error - Errors from parsing a History-Info header value (RFC 7044).
- SipCall
Info Error - Errors from parsing a SIP Call-Info header value.
- SipGeolocation
Ref - A reference extracted from a SIP Geolocation header (RFC 6442).
- SipInvite
Header - Raw SIP INVITE headers preserved verbatim as channel variables.
- Sofia
Variable - mod_sofia / SIP channel variable names (the part after the
variable_prefix).
Traits
- Variable
Name - Trait for typed channel variable name enums.