Module variables

Module variables 

Channel variable types: format parsers (ARRAY::, SIP multipart) and typed variable name enums.

Structs

EslArray
Parses FreeSWITCH ARRAY::item1|:item2|:item3 format
MultipartBody
Parses variable_sip_multipart ARRAY:: format.
MultipartItem
A single part from a SIP multipart body
ParseChannelVariableError
Error returned when parsing an unrecognized channel variable name.
ParseSipInviteHeaderError
Error returned when parsing an unrecognized SIP invite header variable name.
ParseSofiaVariableError
Error returned when parsing an unrecognized Sofia variable name.
SipCallInfo
Parsed SIP Call-Info header value. Contains zero or more entries.
SipCallInfoEntry
One entry from a SIP Call-Info header: <uri>;key=value;key=value.
SipGeolocation
Parsed SIP Geolocation header value (RFC 6442).

Enums

ChannelVariable
Core FreeSWITCH channel variable names (the part after the variable_ prefix).
SipCallInfoError
Errors from parsing a SIP Call-Info header value.
SipGeolocationRef
A reference extracted from a SIP Geolocation header (RFC 6442).
SipInviteHeader
Raw SIP INVITE headers preserved verbatim as channel variables.
SofiaVariable
mod_sofia / SIP channel variable names (the part after the variable_ prefix).

Traits

VariableName
Trait for typed channel variable name enums.