Module variables

Module variables 

Channel variable types: format parsers (ARRAY::, SIP multipart) and typed variable name enums.

Structs

EslArray
Parses FreeSWITCH ARRAY::item1|:item2|:item3 format
MultipartBody
Parses variable_sip_multipart ARRAY:: format.
MultipartItem
A single part from a SIP multipart body
ParseChannelVariableError
Error returned when parsing an unrecognized channel variable name.
ParseSofiaVariableError
Error returned when parsing an unrecognized Sofia variable name.

Enums

ChannelVariable
Core FreeSWITCH channel variable names (the part after the variable_ prefix).
SofiaVariable
mod_sofia / SIP channel variable names (the part after the variable_ prefix).

Traits

VariableName
Trait for typed channel variable name enums.