Channel variable types: format parsers (ARRAY::, SIP multipart) and typed
variable name enums.
Structs
- EslArray
- Parses FreeSWITCH
ARRAY::item1|:item2|:item3format - Multipart
Body - Parses
variable_sip_multipartARRAY:: format. - Multipart
Item - A single part from a SIP multipart body
- Parse
Channel Variable Error - Error returned when parsing an unrecognized channel variable name.
- Parse
Sofia Variable Error - Error returned when parsing an unrecognized Sofia variable name.
Enums
- Channel
Variable - Core FreeSWITCH channel variable names (the part after the
variable_prefix). - Sofia
Variable - mod_sofia / SIP channel variable names (the part after the
variable_prefix).
Traits
- Variable
Name - Trait for typed channel variable name enums.