SipCallInfo

Struct SipCallInfo 

pub struct SipCallInfo(/* private fields */);
Parsed SIP Call-Info header value. Contains zero or more entries.

Accepts both standard comma-separated SIP format and FreeSWITCH ARRAY::|: encoding.

use freeswitch_types::variables::SipCallInfo;

let raw = "<urn:example:call:123>;purpose=emergency-CallId,<https://example.com/data>;purpose=EmergencyCallData.ServiceInfo";
let info = SipCallInfo::parse(raw).unwrap();
assert_eq!(info.entries().len(), 2);
assert_eq!(info.entries()[0].purpose(), Some("emergency-CallId"));

Implementations

Source

impl SipCallInfo

pub fn parse(raw: &str) -> Result<Self, SipCallInfoError>

Parse a raw Call-Info header value. Handles both standard comma-separated SIP format and FreeSWITCH ARRAY::|: encoding.

pub fn entries(&self) -> &[SipCallInfoEntry]

The parsed entries as a slice.

pub fn into_entries(self) -> Vec<SipCallInfoEntry>

Consume self and return the entries as a Vec.

pub fn len(&self) -> usize

Number of entries.

pub fn is_empty(&self) -> bool

Returns true if there are no entries.

pub fn find_by_purpose_suffix(&self, suffix: &str) -> Option<&SipCallInfoEntry>

Find the first entry whose purpose parameter ends with the given suffix (case-insensitive).

pub fn filter_by_purpose_suffix<'a>( &'a self, suffix: &'a str, ) -> impl Iterator<Item = &'a SipCallInfoEntry>

Iterate over entries whose purpose parameter ends with the given suffix (case-insensitive).